Data.HEPEVT
Description
This modules provides a pure haskell implementation of a reader and writer for the ASCII HEPEVT file format.
Documentation
parseEventFile :: String -> IO [Event]Source
parseEvents :: String -> ByteString -> [Event]Source
hepevt-0.1: HEPEVT parser and writer
Data.HEPEVT
Description
This modules provides a pure haskell implementation of a reader and writer for the ASCII HEPEVT file format.
parseEventFile :: String -> IO [Event]Source
parseEvents :: String -> ByteString -> [Event]Source